==> qtjambi-qt3dcore-debuginfo-macos-6.5.3.jar: sources/QtJambi3DCore/QBackendNode_shell.cpp <==
#include "QBackendNode_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QBackendNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QBackendNode")
    Qt3DCore::QBackendNode *_ptr = reinterpret_cast<Qt3DCore::QBackendNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QBackendNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QBackendNode_shell) ); }

jmethodID QBackendNode_shell::__shell_javaMethod(int pos) const { return QBackendNode_shell::__shell()->javaMethod(typeid(Qt3DCore::QBackendNode), pos); }

// emitting (writeShellConstructor)
QBackendNode_shell::QBackendNode_shell(Qt3DCore::QBackendNode::Mode mode0)
    : Qt3DCore::QBackendNode(mode0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QBackendNode::QBackendNode_shell(Qt3DCore::QBackendNode::Mode mode0)", QBackendNode_shell::__shell())
    QBackendNode_shell::__shell()->constructed(typeid(Qt3DCore::QBackendNode));
}

// emitting (writeShellDestructor)
QBackendNode_shell::~QBackendNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QBackendNode::~Qt3DCore::QBackendNode()", QBackendNode_shell::__shell())
    QBackendNode_shell::__shell()->destructed(typeid(Qt3DCore::QBackendNode));
}

void QBackendNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QBackendNode_shell*>(ptr)->QBackendNode_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QBackendNode));
}

// emitting Virtual overrides (virtualFunctions)
void QBackendNode_shell::syncFromFrontEnd(const Qt3DCore::QNode* frontEnd0, bool firstTime1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)", QBackendNode_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QBackendNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_frontEnd0 = qtjambi_cast<jobject>(__jni_env, frontEnd0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_frontEnd0, firstTime1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QBackendNode_shell::__shell()->warnForMethod("Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)");
            } QTJAMBI_TRY_END
        }else{
            Qt3DCore::QBackendNode::syncFromFrontEnd(frontEnd0, static_cast<bool>(firstTime1));
        }
    }else{
        Qt3DCore::QBackendNode::syncFromFrontEnd(frontEnd0, static_cast<bool>(firstTime1));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QBackendNode_access::__qt_syncFromFrontEnd_const_Qt3DCore_QNode_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID frontEnd0, jboolean firstTime1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const Qt3DCore::QNode* __qt_frontEnd0 = QtJambiAPI::objectFromNativeId<Qt3DCore::QNode>(frontEnd0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        Qt3DCore::QBackendNode::syncFromFrontEnd(__qt_frontEnd0, static_cast<bool>(firstTime1));
    } else {
        syncFromFrontEnd(__qt_frontEnd0, static_cast<bool>(firstTime1));
    }
}

// emitting (writeConstructors)
// new QBackendNode(Qt3DCore::QBackendNode::Mode)
void __qt_construct_Qt3DCore_QBackendNode_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBackendNode(Qt3DCore::QBackendNode::Mode)")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QBackendNode *__qt_this = new(__qtjambi_ptr) QBackendNode_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QBackendNode(Qt3DCore::QBackendNode::Mode)
void __qt_construct_Qt3DCore_QBackendNode_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBackendNode(Qt3DCore::QBackendNode::Mode)")
    jobject mode0 = __java_arguments[0].l;
    Qt3DCore::QBackendNode::Mode __qt_mode0 = qtjambi_cast<Qt3DCore::QBackendNode::Mode>(__jni_env, mode0);
    Qt3DCore::QBackendNode *__qt_this = new(__qtjambi_ptr) QBackendNode_shell(Qt3DCore::QBackendNode::Mode(__qt_mode0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QBackendNode_shell
void __qt_destruct_Qt3DCore_QBackendNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QBackendNode")
    reinterpret_cast<QBackendNode_shell*>(ptr)->~QBackendNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QBackendNode::QBackendNode(Qt3DCore::QBackendNode::Mode)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_initialize_1native__Lio_qt_qt3d_core_QBackendNode_2Lio_qt_qt3d_core_QBackendNode_00024Mode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject mode0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QBackendNode::QBackendNode(Qt3DCore::QBackendNode::Mode)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = mode0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QBackendNode_1, sizeof(QBackendNode_shell), typeid(Qt3DCore::QBackendNode), true, &deleter_Qt3DCore_QBackendNode, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QBackendNode::isEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_isEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::isEnabled()const", __qt_this)
        __java_return_value = __qt_this->isEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QBackendNode::mode()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_mode_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::mode()const", __qt_this)
        Qt3DCore::QBackendNode::Mode __qt_return_value = __qt_this->mode();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QBackendNode::peerId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_peerId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::peerId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->peerId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QBackendNode::setEnabled(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_setEnabled_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean enabled0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::setEnabled(bool)", __qt_this)
        __qt_this->setEnabled(static_cast<bool>(enabled0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_syncFromFrontEnd_1native_1const_1Qt3DCore_1QNode_1ptr_1bool__JJZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID frontEnd0,
 jboolean firstTime1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)", __qt_this)
        static_cast<QBackendNode_access*>(__qt_this)->__qt_syncFromFrontEnd_const_Qt3DCore_QNode_ptr_bool(__jni_env, __this_nativeId, frontEnd0, firstTime1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QBackendNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QBackendNode>("Qt3DCore::QBackendNode", "io/qt/qt3d/core/QBackendNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "syncFromFrontEnd", "(Lio/qt/qt3d/core/QNode;Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QBackendNode, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QBackendNode_0, nullptr)
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QBackendNode_1, "Lio/qt/qt3d/core/QBackendNode$Mode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QBackendNode);
    registerSizeOfShell(typeId, sizeof(QBackendNode_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<Qt3DCore::QBackendNode::Mode>("Qt3DCore::QBackendNode::Mode", "io/qt/qt3d/core/QBackendNode$Mode");
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-macos-6.6.3.jar: sources/QtJambi3DCore/QBackendNode_shell.cpp <==
#include "QBackendNode_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QBackendNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QBackendNode")
    Qt3DCore::QBackendNode *_ptr = reinterpret_cast<Qt3DCore::QBackendNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QBackendNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QBackendNode_shell) ); }

jmethodID QBackendNode_shell::__shell_javaMethod(int pos) const { return QBackendNode_shell::__shell()->javaMethod(typeid(Qt3DCore::QBackendNode), pos); }

// emitting (writeShellConstructor)
QBackendNode_shell::QBackendNode_shell(Qt3DCore::QBackendNode::Mode mode0)
    : Qt3DCore::QBackendNode(mode0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QBackendNode::QBackendNode_shell(Qt3DCore::QBackendNode::Mode mode0)", QBackendNode_shell::__shell())
    QBackendNode_shell::__shell()->constructed(typeid(Qt3DCore::QBackendNode));
}

// emitting (writeShellDestructor)
QBackendNode_shell::~QBackendNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QBackendNode::~Qt3DCore::QBackendNode()", QBackendNode_shell::__shell())
    QBackendNode_shell::__shell()->destructed(typeid(Qt3DCore::QBackendNode));
}

void QBackendNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QBackendNode_shell*>(ptr)->QBackendNode_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QBackendNode));
}

// emitting Virtual overrides (virtualFunctions)
void QBackendNode_shell::syncFromFrontEnd(const Qt3DCore::QNode* frontEnd0, bool firstTime1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)", QBackendNode_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QBackendNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_frontEnd0 = qtjambi_cast<jobject>(__jni_env, frontEnd0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_frontEnd0, firstTime1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QBackendNode_shell::__shell()->warnForMethod("Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)");
            } QTJAMBI_TRY_END
        }else{
            Qt3DCore::QBackendNode::syncFromFrontEnd(frontEnd0, static_cast<bool>(firstTime1));
        }
    }else{
        Qt3DCore::QBackendNode::syncFromFrontEnd(frontEnd0, static_cast<bool>(firstTime1));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QBackendNode_access::__qt_syncFromFrontEnd_const_Qt3DCore_QNode_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID frontEnd0, jboolean firstTime1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const Qt3DCore::QNode* __qt_frontEnd0 = QtJambiAPI::objectFromNativeId<Qt3DCore::QNode>(frontEnd0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        Qt3DCore::QBackendNode::syncFromFrontEnd(__qt_frontEnd0, static_cast<bool>(firstTime1));
    } else {
        syncFromFrontEnd(__qt_frontEnd0, static_cast<bool>(firstTime1));
    }
}

// emitting (writeConstructors)
// new QBackendNode(Qt3DCore::QBackendNode::Mode)
void __qt_construct_Qt3DCore_QBackendNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBackendNode(Qt3DCore::QBackendNode::Mode)")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QBackendNode *__qt_this = new(__qtjambi_ptr) QBackendNode_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QBackendNode(Qt3DCore::QBackendNode::Mode)
void __qt_construct_Qt3DCore_QBackendNode_Qt3DCore_QBackendNode_Mode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBackendNode(Qt3DCore::QBackendNode::Mode)")
    jobject mode0 = __java_arguments[0].l;
    Qt3DCore::QBackendNode::Mode __qt_mode0 = qtjambi_cast<Qt3DCore::QBackendNode::Mode>(__jni_env, mode0);
    Qt3DCore::QBackendNode *__qt_this = new(__qtjambi_ptr) QBackendNode_shell(Qt3DCore::QBackendNode::Mode(__qt_mode0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QBackendNode::QBackendNode(Qt3DCore::QBackendNode::Mode)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_initialize_1native__Lio_qt_qt3d_core_QBackendNode_2Lio_qt_qt3d_core_QBackendNode_00024Mode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject mode0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QBackendNode::QBackendNode(Qt3DCore::QBackendNode::Mode)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = mode0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QBackendNode_Qt3DCore_QBackendNode_Mode, sizeof(QBackendNode_shell), typeid(Qt3DCore::QBackendNode), true, &deleter_Qt3DCore_QBackendNode, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBackendNode_shell
void __qt_destruct_Qt3DCore_QBackendNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QBackendNode")
    reinterpret_cast<QBackendNode_shell*>(ptr)->~QBackendNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QBackendNode::isEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_isEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::isEnabled()const", __qt_this)
        __java_return_value = __qt_this->isEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QBackendNode::mode()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_mode_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::mode()const", __qt_this)
        Qt3DCore::QBackendNode::Mode __qt_return_value = __qt_this->mode();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QBackendNode::peerId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_peerId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::peerId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->peerId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QBackendNode::setEnabled(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_setEnabled_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean enabled0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::setEnabled(bool)", __qt_this)
        __qt_this->setEnabled(static_cast<bool>(enabled0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QBackendNode_syncFromFrontEnd_1native_1const_1Qt3DCore_1QNode_1ptr_1bool__JJZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID frontEnd0,
 jboolean firstTime1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QBackendNode *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QBackendNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)", __qt_this)
        static_cast<QBackendNode_access*>(__qt_this)->__qt_syncFromFrontEnd_const_Qt3DCore_QNode_ptr_bool(__jni_env, __this_nativeId, frontEnd0, firstTime1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QBackendNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QBackendNode>("Qt3DCore::QBackendNode", "io/qt/qt3d/core/QBackendNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "syncFromFrontEnd", "(Lio/qt/qt3d/core/QNode;Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QBackendNode, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QBackendNode, nullptr)
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QBackendNode_Qt3DCore_QBackendNode_Mode, "Lio/qt/qt3d/core/QBackendNode$Mode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QBackendNode);
    registerSizeOfShell(typeId, sizeof(QBackendNode_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<Qt3DCore::QBackendNode::Mode>("Qt3DCore::QBackendNode::Mode", "io/qt/qt3d/core/QBackendNode$Mode");
// END: enums and flags
}
